A dataset containing a list of the model fits for joint models fitted to the
data the first three studies in the simdat2 dataset using the JM
package. Further details of model fits supplied below.
JMfits2A list of 3 jointModel objects, the result of fitting a joint
model using the JM package to the data from the first three studies in the
simdat2 dataset in turn.
These are the results of fitting a joint model using the JM
package separately to the data from the first three studies present in the
simdat2 dataset. This data has three levels, namely the longitudinal
measurements at level 1, nested within individuals (level 2) who are
themselves nested within studies (level 3). The joint models fitted to each
study's data had the same format. The longitudinal sub-model contained a
fixed intercept, time and treatment assignment term, as well as a fixed
time by treatment assignment interaction term, and random intercept and
slope. The survival sub-model contained a fixed treatment assignment term.
The sub-models were linked by inserting both the current value of the
longitudinal trajectory and its first derivative with respect to time into
the survival sub-model. More formally, the longitudinal sub-model had the
following format:
$$Y_{kij} = \beta_{10} + \beta_{11}time + \beta_{12}treat + \beta_{13}time*treat+ b^{(2)}_{0ki} + b^{(2)}_{1ki}time + \epsilon_{kij}$$
Where \(Y\) represents the continuous longitudinal outcome, fixed effect coefficients are represented by \(\beta\), random effects coefficients by \(b\) and the measurement error by \(\epsilon\). For the random effects the superscript of 2 indicates that these are individual level, or level 2 random effects. This means they take can take a unique value for each individual in the dataset. The longitudinal time variable is represented by \(time\), and the treatment assignment variable (a binary factor) is represented by \(treat\).
The survival sub-model had format:
$$\lambda_{ki}(t) = \lambda_{0}(t)exp(\beta_{21}treat + \alpha_{1}(\beta_{10} + \beta_{11}time + \beta_{12}treat + + \beta_{13}time*treat b^{(2)}_{0ki} + b^{(2)}_{1ki}time)+ \alpha_{2}(\beta_{11} + \beta_{13}treat + b^{(2)}_{1ki})) $$
In the above equation, \(\lambda_{ki}(t)\) represents the survival time of the individual \(i\) in study \(k\), and \(\lambda_{0}(t)\) represents the baseline hazard, which was modelled using splines. The fixed effect coefficient is represented by \(\beta_{21}\). Association parameters representing the link between the sub-models are represented by \(\alpha\) terms, where \(\alpha_{1}\) represents the effect of the current value of the longitudinal outcome on the risk of an event, whilst \(\alpha_{2}\) represents the effect of the slope, or rate of change of the longitudinal trajectory (the value of the first derivative of the longitudinal trajectory with respect to time) on the risk of an event. Again \(treat\) represents the binary facator treatment assignment variable, and \(b^{(2)}_{0ki}\) and \(b^{(2)}_{1ki}\) are the zero mean random effects from the longitudinal sub-model.
We differentiate between the fixed effect coefficients in the longitudinal and the survival sub-models by varying the first number present in the subscript of the fixed effect, which takes a 1 for coefficients from the longitudinal sub-model and a 2 for coefficients from the survival sub-model.
These fits have been provided in this package for use with the package vignette, see the vignette for more information.