Learn R Programming

joineRmeta (version 0.1.2)

jointmeta1SE.object: A jointmeta1SE object

Description

An object returned by the jointmetaSE function, inheriting from class jointmeta1SE representing the results of bootstrapping a fit from the jointmeta1 function. Objects of this class have methods for the print.jointmeta1SE and vcov.jointmeta1SE functions.

Usage

jointmeta1SE.object

Arguments

Value

A list with the following components.

results

a data frame containing the estimates, standard errors and 95% confidence intervals for the parameters from the model and any overall effects requested.

covmat

the covariance matrix for the model parameters

bootstraps

a data frame containing the results of each bootstrap

Format

An object of class NULL of length 0.

See Also

jointmeta1, jointmetaSE.