jointmeta1SE objectAn object returned by the jointmetaSE function, inheriting from class
jointmeta1SE representing the results of bootstrapping a fit from the
jointmeta1 function. Objects of this class have methods for the
print.jointmeta1SE and vcov.jointmeta1SE functions.
jointmeta1SE.objectA list with the following components.
resultsa data frame containing the estimates, standard errors and 95% confidence intervals for the parameters from the model and any overall effects requested.
covmatthe covariance matrix for the model parameters
bootstrapsa data frame containing the results of each bootstrap
An object of class NULL of length 0.